local HOOKS = {};

function ExtDressingRoom_OnLoad(self)

    self:RegisterEvent("ADDON_LOADED");
    HOOKS["Model_Reset"] = Model_Reset;
    Model_Reset = ExtDressingRoom_Model_Reset;

end

function ExtDressingRoom_OnEvent(self, event, ...)

    if (event == "ADDON_LOADED") then
        local addon = ...;
        if (addon == "ExtDressingRoom") then
            ExtDressingRoom_Setup();
        end
    end

end

function ExtDressingRoom_Setup()

    ExtDressingRoom_RebuildFrame();
    ExtDressingRoom_RebuildSideFrame();

end

function ExtDressingRoom_RebuildFrame()

    local subFrame = CreateFrame("Frame", "DressUpFrameSubFrame", DressUpFrame, "ButtonFrameTemplate");
    subFrame:SetWidth(452);
    subFrame:SetHeight(424);
    subFrame:SetPoint("TOPLEFT", DressUpFrame, "TOPLEFT", 14, -14);
    subFrame:EnableMouse(true);
    subFrame:SetFrameLevel(0);

    -- hide old frame background textures
    local list = { DressUpFrame:GetRegions() };
    for i, j in pairs(list) do
        if j:IsObjectType("Texture") and not j:GetName() then
            j:Hide();
        end
    end

    -- hide unneeded elements from new frame container
    DressUpFrameSubFrameCloseButton:Hide();

    -- re-parent elements to new frame container
    DressUpFramePortrait:SetParent(subFrame);
    DressUpFramePortrait:SetDrawLayer("ARTWORK");
    DressUpFrameTitleText:SetParent(subFrame);
    DressUpFrameDescriptionText:SetParent(subFrame);
    --DressUpModel:SetParent(subFrame);
    DressUpBackgroundTopLeft:SetParent(subFrame);
    DressUpBackgroundTopRight:SetParent(subFrame);
    DressUpBackgroundBotLeft:SetParent(subFrame);
    DressUpBackgroundBotRight:SetParent(subFrame);

    -- resize decorative background to fit new frame
    DressUpBackgroundTopLeft:SetWidth(353);
    DressUpBackgroundTopRight:SetWidth(86);
    DressUpBackgroundBotLeft:SetWidth(353);
    DressUpBackgroundBotRight:SetWidth(86);

    DressUpModel:ClearAllPoints();
    DressUpModel:SetPoint("BOTTOM", DressUpFrame, "BOTTOM", -11, 43);

    DressUpFrameCancelButton:ClearAllPoints();
    DressUpFrameCancelButton:SetPoint("BOTTOMRIGHT", DressUpFrame, "BOTTOMRIGHT", -40, 18);
    DressUpFrame:SetWidth(500);
    DressUpFrame:SetHeight(450);
    DressUpModel:SetWidth(432);
    ExtDressingRoom_ResetPosition(DressUpModel);

end

function ExtDressingRoom_RebuildSideFrame()

    SideDressUpFrame:SetWidth(300);
    SideDressUpFrameTop:Hide();
    -- hide old frame background textures
    local list = { SideDressUpFrame:GetRegions() };
    for i, j in pairs(list) do
        if j:IsObjectType("Texture") and not j:GetName() then
            j:Hide();
        end
    end

    local bgtl = SideDressUpFrame:CreateTexture("SideDressUpFrameTopLeft", "BACKGROUND");
    bgtl:SetPoint("TOPLEFT");
    bgtl:SetWidth(256);
    bgtl:SetHeight(256);
    bgtl:SetTexture("Interface\\AddOns\\ExtDressingRoom\\textures\\topleft");
    local bgtr = SideDressUpFrame:CreateTexture("SideDressUpFrameTopRight", "BACKGROUND");
    bgtr:SetPoint("TOPLEFT", bgtl, "TOPRIGHT", 0, 0);
    bgtr:SetWidth(128);
    bgtr:SetHeight(256);
    bgtr:SetTexture("Interface\\AddOns\\ExtDressingRoom\\textures\\topright");
    local bgbl = SideDressUpFrame:CreateTexture("SideDressUpFrameBotLeft", "BACKGROUND");
    bgbl:SetPoint("TOPLEFT", bgtl, "BOTTOMLEFT", 0, 0);
    bgbl:SetWidth(256);
    bgbl:SetHeight(256);
    bgbl:SetTexture("Interface\\AddOns\\ExtDressingRoom\\textures\\botleft");
    local bgbr = SideDressUpFrame:CreateTexture("SideDressUpFrameBotRight", "BACKGROUND");
    bgbr:SetPoint("TOPLEFT", bgbl, "TOPRIGHT", 0, 0);
    bgbr:SetWidth(128);
    bgbr:SetHeight(256);
    bgbr:SetTexture("Interface\\AddOns\\ExtDressingRoom\\textures\\botright");

    SideDressUpFrameBackgroundTop:SetWidth(284);
    SideDressUpFrameBackgroundBot:SetWidth(284);

    SideDressUpModelResetButton:ClearAllPoints();
    SideDressUpModelResetButton:SetPoint("BOTTOM", SideDressUpModel, "BOTTOM", 0, 20);

end

function ExtDressingRoom_Model_Reset(self)

    HOOKS["Model_Reset"](self);

    if (self:GetName() == "DressUpModel") then
        ExtDressingRoom_ResetPosition(self);
    end

end

function ExtDressingRoom_ResetPosition(model)

    model:SetPosition(-1.8, 0, -0.2);

end
